<?php
/*
 *  $Id: RecordAbstract.php 272 2011-04-25 21:18:23Z k42b3.x $
 *
 * psx
 * A object oriented and modular based PHP framework for developing
 * dynamic web applications. For the current version and informations
 * visit <http://phpsx.org>
 *
 * Copyright (c) 2011 Christoph Kappestein <k42b3.x@gmail.com>
 *
 * This file is part of psx. psx is free software: you can
 * redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or any later version.
 *
 * psx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psx. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PSX_Data_RecordAbstract
 *
 * @author     Christoph Kappestein <k42b3.x@gmail.com>
 * @license    http://www.gnu.org/licenses/gpl.html GPLv3
 * @link       http://phpsx.org
 * @category   PSX
 * @package    PSX_Data
 * @version    $Revision: 272 $
 */
abstract class PSX_Data_RecordAbstract implements PSX_Data_RecordInterface
{
	public function getData()
	{
		return $this->getFields();
	}

	public function hasFields()
	{
		$fields = func_get_args();

		foreach($fields as $field)
		{
			if(!isset($this->$field))
			{
				return false;
			}
		}

		return true;
	}

	public function getFields()
	{
		$fields = array();
		$cols   = $this->getCols();

		foreach($cols as $col)
		{
			if(isset($this->$col))
			{
				$fields[$col] = $this->$col;
			}
		}

		return $fields;
	}

	/**
	 * import
	 *
	 * Override this method if you want that the record can import data from
	 * and PSX_Data_ReaderResult object
	 *
	 * @param PSX_Data_ReaderResult $result
	 * @return void
	 */
	public function import(PSX_Data_ReaderResult $result)
	{
	}

	/**
	 * export
	 *
	 * @param integer $writerType
	 * @return mixed
	 */
	public function export(PSX_Data_WriterResult $result)
	{
		return null;
	}
}

