<?php
/*
 *  $Id: Xml.php 290 2011-06-04 21:59:18Z k42b3.x@googlemail.com $
 *
 * psx
 * A object oriented and modular based PHP framework for developing
 * dynamic web applications. For the current version and informations
 * visit <http://phpsx.org>
 *
 * Copyright (c) 2009 Christoph Kappestein <k42b3.x@gmail.com>
 *
 * This file is part of psx. psx is free software: you can
 * redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or any later version.
 *
 * psx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psx. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PSX_Data_Writer_Xml
 *
 * @author     Christoph Kappestein <k42b3.x@gmail.com>
 * @license    http://www.gnu.org/licenses/gpl.html GPLv3
 * @link       http://phpsx.org
 * @category   PSX
 * @package    PSX_Data
 * @version    $Revision: 290 $
 */
class PSX_Data_Writer_Xml implements PSX_Data_WriterInterface
{
	public static $mime = 'application/xml';

	protected $writer;

	public function write(PSX_Data_RecordInterface $record)
	{
		$this->writer = new XMLWriter();

		$this->writer->openURI('php://output');

		$this->writer->setIndent(true);

		$this->writer->startDocument('1.0', 'UTF-8');

		$writerResult = new PSX_Data_WriterResult(PSX_Data_WriterInterface::XML, $this);

		$this->recXmlEncode($record->getName(), $record->export($writerResult));

		$this->writer->endDocument();
	}

	protected function recXmlEncode($name, array $fields, $ns = NULL)
	{
		if($this->isAssocArray($fields))
		{
			$this->writer->startElement($name);

			if($ns !== NULL)
			{
				$this->writer->writeAttribute('xmlns', self::$xmlns);
			}

			foreach($fields as $k => $v)
			{
				if(is_array($v))
				{
					$this->recXmlEncode($k, $v);
				}
				elseif(is_bool($v))
				{
					$this->writer->writeElement($k, $v ? 'true' : 'false');
				}
				else
				{
					$this->writer->writeElement($k, $v);
				}
			}

			$this->writer->endElement();
		}
		else
		{
			foreach($fields as $k => $v)
			{
				if(is_array($v))
				{
					$this->recXmlEncode($name, $v);
				}
				elseif(is_bool($v))
				{
					$this->writer->writeElement($name, $v ? 'true' : 'false');
				}
				else
				{
					$this->writer->writeElement($name, $v);
				}
			}
		}
	}

	private function isAssocArray(array $array)
	{
		$len = count($array);

		for($i = 0; $i < $len; $i++)
		{
			if(!isset($array[$i]))
			{
				return true;
			}
		}

		return false;
	}
}
