<?php
/*
 *  $Id: Length.php 245 2011-03-24 01:07:52Z k42b3.x $
 *
 * psx
 * A object oriented and modular based PHP framework for developing
 * dynamic web applications. For the current version and informations
 * visit <http://phpsx.org>
 *
 * Copyright (c) 2011 Christoph Kappestein <k42b3.x@gmail.com>
 *
 * This file is part of psx. psx is free software: you can
 * redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or any later version.
 *
 * psx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psx. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PSX_Filter_Length
 *
 * @author     Christoph Kappestein <k42b3.x@gmail.com>
 * @license    http://www.gnu.org/licenses/gpl.html GPLv3
 * @link       http://phpsx.org
 * @category   PSX
 * @package    PSX_Filter
 * @version    $Revision: 245 $
 */
class PSX_Filter_Length extends PSX_FilterAbstract
{
	public function __construct($min = false, $max = false)
	{
		$this->min = $min;
		$this->max = $max;
	}

	/**
	 * apply
	 *
	 * If $value is an integer or float the $min and $max value is meaned as
	 * the current value. If it is a string it is meaned as the length of
	 * $value. If its an array $min and $max relate to the array size.
	 *
	 * @param mixed $value
	 * @return boolean
	 */
	public function apply($value)
	{
		if($this->min === false && $this->max === false)
		{
			return true;
		}
		elseif(is_int($value))
		{
			if($this->min !== false && $this->max === false)
			{
				if($value > $this->min)
				{
					return false;
				}
				else
				{
					return true;
				}
			}

			if($this->min !== false && $this->max !== false)
			{
				if($value >= $this->min && $value <= $this->max)
				{
					return true;
				}
				else
				{
					return false;
				}
			}
		}
		elseif(is_float($value))
		{
			if($this->min !== false && $this->max === false)
			{
				if($value > $this->min)
				{
					return false;
				}
				else
				{
					return true;
				}
			}

			if($this->min !== false && $this->max !== false)
			{
				if($value >= $this->min && $value <= $this->max)
				{
					return true;
				}
				else
				{
					return false;
				}
			}
		}
		elseif(is_string($value))
		{
			if($this->min !== false && $this->max === false)
			{
				if(strlen($value) > $this->min)
				{
					return false;
				}
				else
				{
					return true;
				}
			}

			if($this->min !== false && $this->max !== false)
			{
				if(strlen($value) >= $this->min && strlen($value) <= $this->max)
				{
					return true;
				}
				else
				{
					return false;
				}
			}
		}
		elseif(is_array($value))
		{
			if($this->min !== false && $this->max === false)
			{
				if(count($value) > $this->min)
				{
					return false;
				}
				else
				{
					return true;
				}
			}

			if($this->min !== false && $this->max !== false)
			{
				if(count($value) >= $this->min && count($value) <= $this->max)
				{
					return true;
				}
				else
				{
					return false;
				}
			}
		}

		return false;
	}

	public function getErrorMsg()
	{
		return '%s has an invalid length min ' . $this->min . ' and max ' . $this->max . ' signs';
	}
}
