<?php
/*
 *  $Id: Get.php 260 2011-03-30 20:00:01Z k42b3.x $
 *
 * psx
 * A object oriented and modular based PHP framework for developing
 * dynamic web applications. For the current version and informations
 * visit <http://phpsx.org>
 *
 * Copyright (c) 2011 Christoph Kappestein <k42b3.x@gmail.com>
 *
 * This file is part of psx. psx is free software: you can
 * redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or any later version.
 *
 * psx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psx. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PSX_Get
 *
 * A class to get the $_GET variables. See the PSX_InputAbstract class how
 * you can access values and use the PSX_Validate class. Here a short example
 * how to get a value.
 * <code>
 * $get = new PSX_Get(new PSX_Validate());
 *
 * $id = $get->id('integer');
 * </code>
 *
 * If the $_GET variable id is available it contains an integer representation
 * else of it else false
 *
 * @author     Christoph Kappestein <k42b3.x@gmail.com>
 * @license    http://www.gnu.org/licenses/gpl.html GPLv3
 * @link       http://phpsx.org
 * @category   PSX
 * @package    PSX_Get
 * @version    $Revision: 260 $
 */
class PSX_Get extends PSX_InputAbstract
{
	public function has($key)
	{
		return isset($_GET[$key]);
	}

	public function get($key)
	{
		if($this->has($key))
		{
			return $_GET[$key];
		}
		else
		{
			return false;
		}
	}

	public function set($key, $value)
	{
		$_GET[$key] = $value;
	}

	public function delete($key)
	{
		if($this->has($key))
		{
			unset($_GET[$key]);
		}
	}

	public function getContainer()
	{
		return $_GET;
	}
}

