<?php
/*
 *  $Id: Parse.php 341 2011-10-17 20:12:45Z k42b3.x@googlemail.com $
 *
 * psx
 * A object oriented and modular based PHP framework for developing
 * dynamic web applications. For the current version and informations
 * visit <http://phpsx.org>
 *
 * Copyright (c) 2011 Christoph Kappestein <k42b3.x@gmail.com>
 *
 * This file is part of psx. psx is free software: you can
 * redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or any later version.
 *
 * psx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psx. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PSX_Html_Parse
 *
 * This class is for parsing html. It is especially designed for parsing invalid
 * html. It uses no regexp, simplexml or dom it simply search for strings with
 * the basic php string functions mostly strpos and substr so its is fast and
 * you can proccess big string with it.
 *
 * @author     Christoph Kappestein <k42b3.x@gmail.com>
 * @license    http://www.gnu.org/licenses/gpl.html GPLv3
 * @link       http://phpsx.org
 * @category   PSX
 * @package    PSX_Html
 * @version    $Revision: 341 $
 */
class PSX_Html_Parse
{
	private $head;
	private $body;
	private $content;

	public function __construct($content)
	{
		$this->head    = current(self::getContent($content, 'head'));
		$this->body    = current(self::getContent($content, 'body'));
		$this->content = $content;
	}

	public function getHead()
	{
		return $this->head;
	}

	public function getBody()
	{
		return $this->body;
	}

	/**
	 * fetchAttrFromHead
	 *
	 * This method search for the PSX_Html_Parse_Element in the head section
	 * of an html document. If the element is found it returns the attribute
	 * $return.
	 *
	 * @param PSX_Html_Parse_Element $element
	 * @param string $return
	 * @return false|string
	 */
	public function fetchAttrFromHead(PSX_Html_Parse_Element $element, $return = false)
	{
		$matches = self::getTags($this->head, $element->getName());

		foreach($matches as $match)
		{
			if(!empty($match))
			{
				$found = true;
				$attr  = $element->getAttributes();

				foreach($attr as $k => $v)
				{
					if(strcasecmp(self::getAttribute($match, $k), $v) != 0)
					{
						$found = false;

						break;
					}
				}

				if($found === true)
				{
					return self::getAttribute($match, $return);
				}
			}
		}

		return false;
	}

	public static function getTags($content, $tag)
	{
		$pos_s = stripos($content, '<' . $tag);

		if($pos_s !== false)
		{
			$content = substr($content, $pos_s + strlen($tag) + 1);

			$pos_e = stripos($content, '>');

			if($pos_e !== false)
			{
				$data = substr($content, 0, $pos_e);

				if($content !== false)
				{
					return array_merge(array($data), (array) self::getTags($content, $tag));
				}
			}
		}

		return array();
	}

	public static function getAttribute($content, $key)
	{
		$pos = stripos($content, $key);

		if($pos !== false)
		{
			// we have found the attribute now we cut the content
			// to the start of the attribute and search for =
			$content = substr($content, $pos + strlen($key));

			$pos = strpos($content, '=');

			if($pos !== false)
			{
				$content   = ltrim(substr($content, $pos + 1));
				$delimiter = $content[0];
				$value     = '';

				switch($delimiter)
				{
					// we have found normal marks so we look for the
					// next mark to determine the end of the attribute
					case '"':
					case '\'':

						$content = substr($content, 1);

						$pos = strpos($content, $delimiter);

						if($pos !== false)
						{
							$value = substr($content, 0, $pos);
						}

						break;

					// we are unlucky because now we have crappy html
					// so we try to parse the content until we found
					// the next whitespace
					default:

						$i = 0;

						while($content[$i] != ' ')
						{
							$value.= $content[$i];

							$i++;
						}

						break;
				}

				return empty($value) ? false : $value;
			}
		}

		return false;
	}

	public static function getContent($content, $tag)
	{
		$pos_s = stripos($content, '<' . $tag);

		if($pos_s !== false)
		{
			$content = substr($content, $pos_s + strlen($tag) + 1);

			$pos_e = stripos($content, '</' . $tag . '>');

			if($pos_e !== false)
			{
				$data = substr($content, 0, $pos_e);

				if($content !== false)
				{
					return array_merge(array($data), (array) self::getContent($content, $tag));
				}
			}
		}

		return array();
	}
}
