<?php
/*
 *  $Id: Log.php 245 2011-03-24 01:07:52Z k42b3.x $
 *
 * psx
 * A object oriented and modular based PHP framework for developing
 * dynamic web applications. For the current version and informations
 * visit <http://phpsx.org>
 *
 * Copyright (c) 2011 Christoph Kappestein <k42b3.x@gmail.com>
 *
 * This file is part of psx. psx is free software: you can
 * redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or any later version.
 *
 * psx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psx. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PSX_Log
 *
 * The class offers a basic log functionallity. The following example shows how
 * you can use this class.
 * <code>
 * $handler = new PSX_Log_File_Handler('log.txt');
 * $log     = new PSX_Log($handler, PSX_Log::$DEBUG);
 *
 * if($isAdmin === true)
 * {
 * 	$log->INFO($_SERVER['REMOTE_ADDR'] . ' has entered admin area');
 * }
 * </code>
 *
 * @author     Christoph Kappestein <k42b3.x@gmail.com>
 * @license    http://www.gnu.org/licenses/gpl.html GPLv3
 * @link       http://phpsx.org
 * @category   PSX
 * @package    PSX_Log
 * @version    $Revision: 245 $
 */
class PSX_Log
{
	public static $ALL   = 0x7;
	public static $TRACE = 0x6;
	public static $DEBUG = 0x5;
	public static $INFO  = 0x4;
	public static $WARN  = 0x3;
	public static $ERROR = 0x2;
	public static $FATAL = 0x1;
	public static $OFF   = 0x0;

	private $level;
	private $handler;

	public function __construct(PSX_Log_HandlerInterface $handler, $logLevel = false)
	{
		$this->handler = $handler;
		$this->level   = $logLevel >= 0x0 && $logLevel <= 0x7 ? $logLevel : self::$WARNING;
	}

	public function FATAL($msg)
	{
		if(self::$FATAL <= $this->level)
		{
			$this->handler->write('FATAL', $msg);
		}
	}

	public function ERROR($msg)
	{
		if(self::$ERROR <= $this->level)
		{
			$this->handler->write('ERROR', $msg);
		}
	}

	public function WARN($msg)
	{
		if(self::$WARN <= $this->level)
		{
			$this->handler->write('WARN', $msg);
		}
	}

	public function INFO($msg)
	{
		if(self::$INFO <= $this->level)
		{
			$this->handler->write('INFO', $msg);
		}
	}

	public function DEBUG($msg)
	{
		if(self::$DEBUG <= $this->level)
		{
			$this->handler->write('DEBUG', $msg);
		}
	}

	public function TRACE($msg)
	{
		if(self::$TRACE <= $this->level)
		{
			$this->handler->write('TRACE', $msg);
		}
	}

	public static function level($level = false)
	{
		$levels = array(

			self::$FATAL => 'FATAL',
			self::$ERROR => 'ERROR',
			self::$WARN  => 'WARN',
			self::$INFO  => 'INFO',
			self::$DEBUG => 'DEBUG',
			self::$TRACE => 'TRACE',

		);

		return isset($levels[$level]) ? $levels[$level] : 'UNKNOWN';
	}
}
