<?php
/*
 *  $Id: ModuleAbstract.php 274 2011-04-27 21:43:46Z k42b3.x $
 *
 * psx
 * A object oriented and modular based PHP framework for developing
 * dynamic web applications. For the current version and informations
 * visit <http://phpsx.org>
 *
 * Copyright (c) 2011 Christoph Kappestein <k42b3.x@gmail.com>
 *
 * This file is part of psx. psx is free software: you can
 * redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or any later version.
 *
 * psx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psx. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PSX_ModuleAbstract
 *
 * @author     Christoph Kappestein <k42b3.x@gmail.com>
 * @license    http://www.gnu.org/licenses/gpl.html GPLv3
 * @link       http://phpsx.org
 * @category   PSX
 * @package    PSX_Module
 * @version    $Revision: 274 $
 */
abstract class PSX_ModuleAbstract
{
	protected $config;
	protected $template;

	protected $basePath;
	protected $uriFragments = array();

	public function __construct(PSX_Config $config, PSX_Template $template, $basePath, array $uriFragments)
	{
		$this->config       = $config;
		$this->template     = $template;

		$this->basePath     = $basePath;
		$this->uriFragments = $uriFragments;
	}

	protected function getBasePath()
	{
		return $this->basePath;
	}

	protected function getUriFragments()
	{
		return $this->uriFragments;
	}

	public function _ini()
	{
		$this->onLoad();

		switch(PSX_Config::getRequestMethod())
		{
			case 'GET':

				$this->onGet();

				break;

			case 'POST':

				$this->onPost();

				break;

			case 'PUT':

				$this->onPut();

				break;

			case 'DELETE':

				$this->onDelete();

				break;
		}
	}

	public function onLoad()
	{
	}

	public function onGet()
	{
	}

	public function onPost()
	{
	}

	public function onPut()
	{
	}

	public function onDelete()
	{
	}

	public function processResponse($response)
	{
	}
}

