<?php
/*
 *  $Id: SetupRequest.php 343 2011-10-18 20:54:47Z k42b3.x@googlemail.com $
 *
 * psx
 * A object oriented and modular based PHP framework for developing
 * dynamic web applications. For the current version and informations
 * visit <http://phpsx.org>
 *
 * Copyright (c) 2011 Christoph Kappestein <k42b3.x@gmail.com>
 *
 * This file is part of psx. psx is free software: you can
 * redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or any later version.
 *
 * psx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psx. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PSX_OpenId_Provider_Data_SetupRequest
 *
 * @author     Christoph Kappestein <k42b3.x@gmail.com>
 * @license    http://www.gnu.org/licenses/gpl.html GPLv3
 * @link       http://phpsx.org
 * @category   PSX
 * @package    PSX_OpenId
 * @version    $Revision: 343 $
 */
class PSX_OpenId_Provider_Data_SetupRequest extends PSX_Data_RecordAbstract
{
	public $claimedId;
	public $identity;
	public $assocHandle;
	public $returnTo;
	public $realm;

	private $params;
	private $map = array(

		'claimedId'   => 'claimed_id',
		'identity'    => 'identity',
		'assocHandle' => 'assoc_handle',
		'returnTo'    => 'return_to',
		'realm'       => 'realm',

	);

	public function getName()
	{
		return 'request';
	}

	public function getFields()
	{
		$fields = array();

		foreach($this->map as $k => $v)
		{
			$value = $this->$k;

			if(!empty($value))
			{
				$fields[$key] = $value;
			}
		}

		return $fields;
	}

	public function setClaimedId($claimedId)
	{
		$this->claimedId = $claimedId;
	}

	public function setIdentity($identity)
	{
		$this->identity = $identity;
	}

	public function setAssocHandle($assocHandle)
	{
		$this->assocHandle = $assocHandle;
	}

	public function setReturnTo($returnTo)
	{
		$this->returnTo = new PSX_Url($returnTo);
	}

	public function setRealm($realm)
	{
		$this->realm = $realm;
	}

	public function getClaimedId()
	{
		return $this->claimedId;
	}

	public function getIdentity()
	{
		return $this->identity;
	}

	public function getAssocHandle()
	{
		return $this->assocHandle;
	}

	public function getReturnTo()
	{
		return $this->returnTo;
	}

	public function getRealm()
	{
		return $this->realm;
	}

	public function getExtension($ns)
	{
		return PSX_OpenId_ProviderAbstract::getExtension($this->params, $ns);
	}

	public function getParams()
	{
		return $this->params;
	}

	public function import(PSX_Data_ReaderResult $result)
	{
		switch($result->getType())
		{
			case PSX_Data_ReaderInterface::RAW:

				$params = $result->getData()->getUrl()->getParams();

				if(isset($params['openid_claimed_id']))
				{
					$this->setClaimedId($params['openid_claimed_id']);

					unset($params['openid_claimed_id']);
				}

				if(isset($params['openid_identity']))
				{
					$this->setIdentity($params['openid_identity']);

					unset($params['openid_identity']);
				}

				if(isset($params['openid_assoc_handle']))
				{
					$this->setAssocHandle($params['openid_assoc_handle']);

					unset($params['openid_assoc_handle']);
				}

				if(isset($params['openid_return_to']))
				{
					$this->setReturnTo($params['openid_return_to']);

					unset($params['openid_return_to']);
				}

				if(isset($params['openid_realm']))
				{
					$this->setRealm($params['openid_realm']);

					unset($params['openid_realm']);
				}

				$this->params = $params;

				break;

			default:

				throw new PSX_Data_Exception('Can only import data from reader Raw');

				break;
		}
	}

	public function export(PSX_Data_WriterResult $result)
	{
		switch($result->getType())
		{
			case PSX_Data_WriterInterface::FORM:
			case PSX_Data_WriterInterface::JSON:
			case PSX_Data_WriterInterface::XML:

				return $this->getFields();

				break;
		}
	}
}