<?php
/*
 *  $Id: Session.php 337 2011-10-10 21:29:32Z k42b3.x@googlemail.com $
 *
 * psx
 * A object oriented and modular based PHP framework for developing
 * dynamic web applications. For the current version and informations
 * visit <http://phpsx.org>
 *
 * Copyright (c) 2011 Christoph Kappestein <k42b3.x@gmail.com>
 *
 * This file is part of psx. psx is free software: you can
 * redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or any later version.
 *
 * psx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psx. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PSX_Session
 *
 * @author     Christoph Kappestein <k42b3.x@gmail.com>
 * @license    http://www.gnu.org/licenses/gpl.html GPLv3
 * @link       http://phpsx.org
 * @category   PSX
 * @package    PSX_Session
 * @version    $Revision: 337 $
 */
class PSX_Session extends PSX_InputAbstract
{
	public function __construct($name, PSX_Validate $validate, PSX_Session_HandlerInterface $handler = null)
	{
		parent::__construct($validate);

		$ip = isset($_SERVER['REMOTE_ADDR'])     ? $_SERVER['REMOTE_ADDR']     : '0.0.0.0';
		$ua = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : 'undefined';

		$key   = 'psx_session_token';
		$token = md5($name . $ip . $ua);

		if($handler !== null)
		{
			session_set_save_handler(

				array($handler, 'open'),
				array($handler, 'close'),
				array($handler, 'read'),
				array($handler, 'write'),
				array($handler, 'delete'),
				array($handler, 'gc')

			);
		}

		session_name($name);

		session_start();

		if($token == $this->get($key))
		{
			// we have an valid token
		}
		else
		{
			$_SESSION       = array();
			$_SESSION[$key] = $token;
		}
	}

	public function has($key)
	{
		return isset($_SESSION[$key]);
	}

	public function get($key)
	{
		if($this->has($key))
		{
			return $_SESSION[$key];
		}
		else
		{
			return false;
		}
	}

	public function set($key, $value)
	{
		$_SESSION[$key] = $value;
	}

	public function delete($key)
	{
		if($this->has($key) === true)
		{
			unset($_SESSION[$key]);
		}
	}

	public function getContainer()
	{
		return $_SESSION;
	}

	public function destroy()
	{
		$_SESSION = array();

		if(isset($_COOKIE[session_name()]))
		{
			setcookie(session_name(), '', time() - 3600);
		}

		session_destroy();
	}
}
