<?php
/*
 *  $Id: TemplateInterface.php 245 2011-03-24 01:07:52Z k42b3.x $
 *
 * psx
 * A object oriented and modular based PHP framework for developing
 * dynamic web applications. For the current version and informations
 * visit <http://phpsx.org>
 *
 * Copyright (c) 2011 Christoph Kappestein <k42b3.x@gmail.com>
 *
 * This file is part of psx. psx is free software: you can
 * redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or any later version.
 *
 * psx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psx. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PSX_Template_TemplateInterface
 *
 * This is the template interface. If you want use another template engine
 * build a class wich implements this interface and implement the following
 * methods like described. In the index.php you have to create instead of the
 * psx_template object the object that you have created.
 *
 * @author     Christoph Kappestein <k42b3.x@gmail.com>
 * @license    http://www.gnu.org/licenses/gpl.html GPLv3
 * @link       http://phpsx.org
 * @category   PSX
 * @package    PSX_Template
 * @version    $Revision: 245 $
 */
interface PSX_Template_TemplateInterface
{
	/**
	 * __construct
	 *
	 * The config object holds the template default settings wich should be
	 * set if the object is created
	 *
	 * @param psx_config $config
	 * @return void
	 */
	public function __construct(PSX_Config $config);

	/**
	 * set
	 *
	 * Sets a template file should return true if it was successfull else
	 * false
	 *
	 * @param string $file
	 * @return boolean
	 */
	public function set($file);

	/**
	 * dir
	 *
	 * Sets the template dir. A template dir is a subfolder in the template
	 * folder and represents a design. All templates are loaded from this
	 * directory. By default we use the dir from the config 'template_dir'.
	 * Should return true if it was successful else false
	 *
	 * @param string $dir
	 * @return boolean
	 */
	public function dir($dir);

	/**
	 * load
	 *
	 * Loads the template file wich was set ... returns true if it was
	 * successful else false
	 *
	 * @return boolean
	 */
	public function load();

	/**
	 * assign
	 *
	 * Assings a variable to the template
	 *
	 * @return void
	 */
	public function assign($key, $value);

	/**
	 * transform
	 *
	 * Transforms the template and returns the transformed content as string
	 *
	 * @return string
	 */
	public function transform();
}

